# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Net-Daemon
Version:	0.49
Release:	9.%{__distinit}%{__distvers}
Summary:	Perl extension for portable daemons
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Net-Daemon
Source0:	https://cpan.metacpan.org/modules/by-module/Net/Net-Daemon-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Config)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Getopt::Long)
BuildRequires:	perl(IO::Socket)
BuildRequires:	perl(POSIX)
BuildRequires:	perl(strict)
BuildRequires:	perl(Symbol)
BuildRequires:	perl(Sys::Syslog) >= 0.29
BuildRequires:	perl(threads)
BuildRequires:	perl(threads::shared)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Fcntl)
BuildRequires:	perl(Socket)
BuildRequires:	perl(Test::More)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Sys::Syslog) >= 0.29
Requires:	perl(threads)
Requires:	perl(threads::shared)

%description
Net::Daemon is an abstract base class for implementing portable server 
applications in a very simple way. The module is designed for Perl 5.006 and 
ithreads (and higher), but can work with fork() and Perl 5.004.

The Net::Daemon class offers methods for the most common tasks a daemon 
needs: Starting up, logging, accepting clients, authorization, restricting 
its own environment for security and doing the true work. You only have to 
override those methods that aren't appropriate for you, but typically 
inheriting will save you a lot of work anyway.

%prep
%setup -q -n Net-Daemon-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc ChangeLog README
%{perl_vendorlib}/Net/
%{_mandir}/man3/Net::Daemon.3*
%{_mandir}/man3/Net::Daemon::Log.3*
%{_mandir}/man3/Net::Daemon::Test.3*

%changelog
* Fri Jul 14 2023 Paul Howarth <paul@city-fan.org> - 0.49-9
- Use SPDX-format license tag

* Sat Sep 26 2020 Paul Howarth <paul@city-fan.org> - 0.49-1
- Update to 0.49
  - Perl 5.6 is the minimum required version now
  - RIP Thread.pm: it has not been relevant since 5.6
  - Now using github CI to monitor the major platforms
  - Add .gitignore for better management
  - Update the MANIFEST
  - Perltidy the code base
  - use strict, warnings, no vars, our
  - Remove perl 4-ish subroutine calls
  - Require Sys::Syslog 0.29 to function properly
  - t/base.t → Test::More
  - Improve skipall messages and detection of ithreads/forks
  - Disable t/ithreadm.t for Windows
    (see https://github.com/toddr/Net-Daemon/issues/19)
  - Only load threads if forks hasn't already been loaded and threads exist
  - Update tracker location to github
  - Fix ReadConfigFile implementation traversing @INC

* Fri May 31 2019 Paul Howarth <paul@city-fan.org> - 0.48-22
- Perl 5.30 rebuild

* Wed Apr 25 2018 Paul Howarth <paul@city-fan.org> - 0.48-18
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Fri Sep  9 2016 Paul Howarth <paul@city-fan.org> - 0.48-14
- Classify buildreqs by usage
- Run all tests where possible
- Simplify find command using -delete
- Drop %%defattr, redundant since rpm 4.4

* Fri Jun  8 2012 Paul Howarth <paul@city-fan.org> - 0.48-3
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Mon Jan 30 2012 Paul Howarth <paul@city-fan.org> - 0.48-2
- Import from Fedora

* Mon Jan 16 2012 Petr Lautrbach <plautrba@redhat.com> - 0.48-1
- Update to 0.48 version
- Fix build requires

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.44-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Jun 17 2011 Marcela Mašláňová <mmaslano@redhat.com> - 0.44-13
- Perl mass rebuild

* Thu Jun 09 2011 Marcela Mašláňová <mmaslano@redhat.com> - 0.44-12
- Perl 5.14 mass rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.44-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Dec 21 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.44-10
- Rebuild to fix problems with vendorarch/lib (#661697)

* Tue May 04 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.44-9
- Mass rebuild with perl-5.12.0

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.44-8
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.44-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.44-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Oct 13 2008 Petr Lautrbach <plautrba@redhat.com> - 0.44-5
- "--with network_tests" - don't remove network tests

* Mon Oct  6 2008 Petr Lautrbach <plautrba@redhat.com> - 0.44-4
- Description and License fixed
- Patch without backup

* Mon Oct  6 2008 Petr Lautrbach <lautrba@redhat.com> - 0.44-3
- Requires: fixed

* Fri Oct  3 2008 Petr Lautrbach <lautrba@redhat.com> - 0.44-2
- Only-ithreads patch added
- Disabled tests that fail under mock

* Fri Sep 26 2008 Petr Lautrbach <lautrba@redhat.com> - 0.44-1
- Initial rpm release
